;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "leetcode" "20250417.1453"
  "An leetcode client."
  '((emacs "28.1")
    (s     "1.13.0")
    (aio   "1.0")
    (log4e "0.3.3"))
  :url "https://github.com/kaiwk/leetcode.el"
  :commit "7f1d6804ed3b9de98d2737e1eab275cd9cbcdb16"
  :revdesc "7f1d6804ed3b"
  :keywords '("extensions" "tools")
  :authors '(("Wang Kai" . "kaiwkx@gmail.com"))
  :maintainers '(("Wang Kai" . "kaiwkx@gmail.com")))
